@@ -36,12 +36,12 @@
 #include <k3bverificationjob.h>
 
 #include <kprocess.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
-#include <kio/global.h>
-#include <kio/job.h>
+#include <tdetempfile.h>
+#include <tdeio/global.h>
+#include <tdeio/job.h>
 
 #include <tqstring.h>
 #include <tqstringlist.h>
@@ -935,10 +935,10 @@ TQString K3bDataJob::jobDetails() const
     return i18n("ISO9660 Filesystem (Size: %1) - %n copy",
 		"ISO9660 Filesystem (Size: %1) - %n copies",
 		d->doc->copies() )
-      .arg(KIO::convertSize( d->doc->size() ));
+      .arg(TDEIO::convertSize( d->doc->size() ));
   else
     return i18n("ISO9660 Filesystem (Size: %1)")
-      .arg(KIO::convertSize( d->doc->size() ));
+      .arg(TDEIO::convertSize( d->doc->size() ));
 }
 
 
